@@ -1,7 +1,7 @@
 /*
  *  UFTP - UDP based FTP with multicast
  *
- *  Copyright (C) 2001-2017   Dennis A. Bush, Jr.   bush@tcnj.edu
+ *  Copyright (C) 2001-2019   Dennis A. Bush, Jr.   bush@tcnj.edu
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -805,6 +805,7 @@ void handle_proxy_key(const union sockaddr_u *src,
             return;
         }
     }
+    proxy_pubkeytype = keyblob[0];
     if (dhlen) {
         if (!import_EC_key(&proxy_dhkey.ec, dhblob, dhlen, 1)) {
             log0(0, 0, 0, "Failed to import ECDH public key from PROXY_KEY");
@@ -1192,7 +1193,7 @@ double loss_event_rate(struct group_list_t *group)
  * Returns the current congestion control rate in bytes / second.
  * As specified in RFC 4654
  */
-unsigned current_cc_rate(struct group_list_t *group)
+int64_t current_cc_rate(struct group_list_t *group)
 {
     double p, rtt;
     int i, bytes, thresh;
@@ -1213,10 +1214,10 @@ unsigned current_cc_rate(struct group_list_t *group)
                    group->loss_history[i].t) < thresh)) {
             bytes += group->loss_history[i--].size;
         }
-        return (unsigned)(2.0 * bytes / (4.0 * group->grtt));
+        return (int64_t)(2.0 * bytes / (4.0 * group->grtt));
     } else {
         glog5(group, "getting cc rate, p=%f, rtt=%f", p, rtt);
-        return (unsigned)(group->datapacketsize /
+        return (int64_t)(group->datapacketsize /
                 (rtt * (sqrt(p * 2.0 / 3.0) +
                         (12 * sqrt(p * 3.0 / 8.0) * p * (1 + (32 * p * p))))));
     }
