@@ -1,7 +1,7 @@
 /*
  *  UFTP - UDP based FTP with multicast
  *
- *  Copyright (C) 2001-2014   Dennis A. Bush, Jr.   bush@tcnj.edu
+ *  Copyright (C) 2001-2019   Dennis A. Bush, Jr.   bush@tcnj.edu
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -162,6 +162,7 @@ void set_defaults(void)
     max_log_size = 0;
     max_log_count = DEF_MAX_LOG_COUNT;
     cache_len = DEF_CACHE;
+    proxy_pubkeytype = 0;
 }
 
 /**
@@ -324,7 +325,7 @@ void process_args(int argc, char *argv[])
             errno = 0;
             uid = strtoul(optarg, NULL, 16);
             if (errno) {
-                perror("Invalid UID\n");
+                perror("Invalid UID");
                 exit(ERR_PARAM);
             }
             uid = htonl(uid);
