@@ -1,7 +1,7 @@
 /*
  *  UFTP - UDP based FTP with multicast
  *
- *  Copyright (C) 2001-2018   Dennis A. Bush, Jr.   bush@tcnj.edu
+ *  Copyright (C) 2001-2019   Dennis A. Bush, Jr.   bush@tcnj.edu
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -214,10 +214,13 @@ void daemonize(void)
             }
         }
 #ifdef VMS
-        chdir("SYS$LOGIN");
+        const char *rootdir = "SYS$LOGIN";
 #else
-        chdir("/");
+        const char *rootdir = "/";
 #endif
+        if (chdir(rootdir) == -1) {
+            perror("Can't change directory");
+        }
         umask(0);
 
         init_log(debug);
