@@ -1,7 +1,7 @@
 /*
  *  UFTP - UDP based FTP with multicast
  *
- *  Copyright (C) 2001-2015   Dennis A. Bush, Jr.   bush@tcnj.edu
+ *  Copyright (C) 2001-2020   Dennis A. Bush, Jr.   bush@tcnj.edu
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -130,6 +130,9 @@ struct timeval *getrecenttimeout(void)
                     if (file_done(group, 1)) {
                         glog2(group, "File transfer complete");
                         send_complete(group, 0);
+                        if (group->phase != PHASE_MIDGROUP) {
+                            print_result_status(group);
+                        }
                         file_cleanup(group, 0);
                     } else if (group->fileinfo.got_done && !sent_naks) {
                         // We didn't send any NAKs since the last time
@@ -306,7 +309,7 @@ void mainloop(void)
             if ((group != NULL) && (group->keytype != KEY_NONE) &&
                     ((header->func == FILEINFO) || (header->func == FILESEG) ||
                      (header->func == DONE) || (header->func == DONE_CONF) ||
-                     ((header->func == ABORT) &&
+                     (header->func == CONG_CTRL) || ((header->func == ABORT) &&
                          (group->phase != PHASE_REGISTERED)))) {
                 glog1(group, "Rejecting %s message from %s: not encrypted",
                              func_name(header->func), rxname);
