@@ -1,7 +1,7 @@
 /*
  *  UFTP - UDP based FTP with multicast
  *
- *  Copyright (C) 2001-2015   Dennis A. Bush, Jr.   bush@tcnj.edu
+ *  Copyright (C) 2001-2018   Dennis A. Bush, Jr.   bush@tcnj.edu
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -93,7 +93,7 @@ int calculate_server_keys(struct pr_group_list_t *group,
     // Sets the first 4 bytes of rand2 to the current time
     t = time(NULL);
     t2 = (uint32_t)(t & 0xFFFFFFFF);
-    *(uint32_t *)(group->rand2) = t2;
+    memcpy(&group->rand2, &t2, sizeof(t2));
     if (group->keyextype == KEYEX_RSA) {
         if (!get_random_bytes(group->premaster, MASTER_LEN)) {
             glog0(group, "Failed to get random bytes for premaster");
