@@ -496,7 +496,7 @@ uint8_t *build_verify_data(const struct finfo_t *finfo, int hostidx,
             uint16_t bloblen;
             uint8_t *keyblob = verifydata + *verifylen;
 
-            if ((keyextype == KEYEX_RSA) || (keyextype == KEYEX_ECDH_RSA)) {
+            if (destlist[hostidx].encinfo->pubkeytype == KEYBLOB_RSA) {
                 if (!export_RSA_key(destlist[hostidx].encinfo->pubkey.rsa,
                                     keyblob, &bloblen)) {
                     free(verifydata);
@@ -530,7 +530,7 @@ int verify_client_key(struct finfo_t *finfo, int hostidx)
     // build_verify_data should never fail in this case
     verifydata = build_verify_data(finfo, hostidx, &verifylen);
 
-    if ((keyextype == KEYEX_RSA) || (keyextype == KEYEX_ECDH_RSA)) {
+    if (destlist[hostidx].encinfo->pubkeytype == KEYBLOB_RSA) {
         if (!verify_RSA_sig(destlist[hostidx].encinfo->pubkey.rsa, hashtype,
                 verifydata, verifylen, destlist[hostidx].encinfo->verifydata,
                 destlist[hostidx].encinfo->verifylen)) {
@@ -799,6 +799,7 @@ int verify_client_fingerprint(const struct finfo_t *finfo,
         return 1;
     }
 
+    destlist[hostidx].encinfo->pubkeytype = keyblob[0];
     if (keyblob[0] == KEYBLOB_RSA) {
         if (!import_RSA_key(&destlist[hostidx].encinfo->pubkey.rsa,
                             keyblob, bloblen)) {
@@ -868,13 +869,15 @@ void handle_open_clientkey(const unsigned char *message, unsigned meslen,
         send_abort(finfo, "Invalid message size", su, src, 0, 0);
         return;
     }
-    if ((((keyextype == KEYEX_RSA) || (keyextype == KEYEX_ECDH_RSA)) &&
-                (keyblob[0] != KEYBLOB_RSA)) ||
-            ((keyextype == KEYEX_ECDH_ECDSA) &&
-             (keyblob[0] != KEYBLOB_EC))) {
-        glog1(finfo, "Rejecting CLIENT_KEY from %08X: "
-                     "invalid keyblob type", ntohl(src));
-        return;
+    if (sigtype == SIG_KEYEX) {
+        if ((((keyextype == KEYEX_RSA) || (keyextype == KEYEX_ECDH_RSA)) &&
+                    (keyblob[0] != KEYBLOB_RSA)) ||
+                ((keyextype == KEYEX_ECDH_ECDSA) &&
+                 (keyblob[0] != KEYBLOB_EC))) {
+            glog1(finfo, "Rejecting CLIENT_KEY from %08X: "
+                         "invalid keyblob type", ntohl(src));
+            return;
+        }
     }
 
     hostidx = add_dest_by_addr(src, finfo, DEST_MUTE, -1, 0);
@@ -911,13 +914,15 @@ void handle_clientkey(const unsigned char *message, unsigned meslen,
         send_abort(finfo, "Invalid message size", su, destlist[hostidx].id,0,0);
         return;
     }
-    if ((((keyextype == KEYEX_RSA) || (keyextype == KEYEX_ECDH_RSA)) &&
-                (keyblob[0] != KEYBLOB_RSA)) ||
-            ((keyextype == KEYEX_ECDH_ECDSA) &&
-             (keyblob[0] != KEYBLOB_EC))) {
-        glog1(finfo, "Rejecting CLIENT_KEY from %s: "
-                     "invalid keyblob type", destlist[hostidx].name);
-        return;
+    if (sigtype == SIG_KEYEX) {
+        if ((((keyextype == KEYEX_RSA) || (keyextype == KEYEX_ECDH_RSA)) &&
+                    (keyblob[0] != KEYBLOB_RSA)) ||
+                ((keyextype == KEYEX_ECDH_ECDSA) &&
+                 (keyblob[0] != KEYBLOB_EC))) {
+            glog1(finfo, "Rejecting CLIENT_KEY from %s: "
+                         "invalid keyblob type", destlist[hostidx].name);
+            return;
+        }
     }
     if (finfo->file_id != 0) {
         glog2(finfo, "Received CLIENT_KEY+ from %s", destlist[hostidx].name);
