@@ -174,7 +174,7 @@ int send_multiple(const struct finfo_t *finfo, unsigned char *packet,
             payloadlen = hsize + (dests * sizeof(uint32_t));
             if (message == ANNOUNCE) {
                 outpacket = packet;
-                if (!sign_announce(finfo, outpacket, payloadlen)) {
+                if (!sign_announce(finfo, outpacket, payloadlen + sizeof(struct uftp_h))) {
                     glog0(finfo, "Error signing ANNOUNCE");
                     free(encpacket);
                     return 0;
