@@ -1,7 +1,7 @@
 /*
  *  UFTP - UDP based FTP with multicast
  *
- *  Copyright (C) 2001-2018   Dennis A. Bush, Jr.   bush@tcnj.edu
+ *  Copyright (C) 2001-2019   Dennis A. Bush, Jr.   bush@tcnj.edu
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -60,8 +60,8 @@
  */
 SOCKET sock;
 union sockaddr_u listen_dest, receive_dest;
-int max_rate, min_rate, init_rate, rate;
-int rcvbuf, packet_wait, txweight, max_nak_pct, max_passes;
+int64_t max_rate, min_rate, init_rate, rate, packet_wait;
+int rcvbuf, txweight, max_nak_pct, max_passes;
 int client_auth, quit_on_error, dscp, follow_links, max_nak_cnt;
 int save_fail, restart_groupid, restart_groupinst, files_sent; 
 int sync_mode, sync_preview, dest_is_dir, cc_type, user_abort;
@@ -328,7 +328,7 @@ static int get_hashtype(const char *name)
 void process_args(int argc, char *argv[])
 {
     int c, i, listidx, read_restart, rval;
-    long tmpval;
+    int64_t tmpval;
     char line[1000], *dest, *destname, filename[MAXPATHNAME], *fingerprint, *p;
     char keylenstr[50];
     struct addrinfo ai_hints, *ai_rval;
@@ -352,8 +352,8 @@ void process_args(int argc, char *argv[])
             break;
         case 'R':
             // Expecting rate as Kbps, translate to B/s
-            rate = atoi(optarg);
-            if ((rate <= 0) && (rate != -1)) {
+            rate = strtoll(optarg, NULL, 0);
+            if (((rate <= 0) && (rate != -1)) || (rate > (1 << 30))) {
                 fprintf(stderr,"Invalid rate\n");
                 exit(ERR_PARAM);
             }
@@ -585,7 +585,7 @@ void process_args(int argc, char *argv[])
             errno = 0;
             server_id = strtoul(optarg, NULL, 16);
             if (errno) {
-                perror("Invalid UID\n");
+                perror("Invalid UID");
                 exit(ERR_PARAM);
             }
             server_id = htonl(server_id);
@@ -689,8 +689,8 @@ void process_args(int argc, char *argv[])
                 if (p) {
                     if (isdigit(*p)) {
                         // For backward compatibility with 4.7 and earlier
-                        max_rate = atoi(p);
-                        if (max_rate <= 0) {
+                        max_rate = strtoll(p, NULL, 0);
+                        if ((max_rate <= 0) || (max_rate > (1 << 30))) {
                             fprintf(stderr, "Invalid max rate\n");
                             exit(ERR_PARAM);
                         }
@@ -708,8 +708,8 @@ void process_args(int argc, char *argv[])
                                 fprintf(stderr, "Invalid rate\n");
                                 exit(ERR_PARAM);
                             }
-                            tmpval = atoi(valp);
-                            if (tmpval <= 0) {
+                            tmpval = strtoll(valp, NULL, 0);
+                            if ((tmpval <= 0) || (tmpval > (1 << 30))) {
                                 fprintf(stderr, "Invalid rate\n");
                                 exit(ERR_PARAM);
                             }
