@@ -1,7 +1,7 @@
 /*
  *  UFTP - UDP based FTP with multicast
  *
- *  Copyright (C) 2001-2019   Dennis A. Bush, Jr.   bush@tcnj.edu
+ *  Copyright (C) 2001-2020   Dennis A. Bush, Jr.   bush@tcnj.edu
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -70,16 +70,15 @@ void cleanup(void)
         if (keytype != KEY_NONE) {
             if (destlist[i].encinfo) {
                 if (destlist[i].encinfo->pubkey.key) {
-                    if ((keyextype == KEYEX_RSA) ||
-                            (keyextype == KEYEX_ECDH_RSA)) {
+                    if (destlist[i].encinfo->pubkeytype == KEYBLOB_RSA) {
                         free_RSA_key(destlist[i].encinfo->pubkey.rsa);
                     } else {
                         free_EC_key(destlist[i].encinfo->pubkey.ec);
                     }
-                    if ((keyextype == KEYEX_ECDH_RSA) ||
-                            (keyextype == KEYEX_ECDH_ECDSA)) {
-                        free_EC_key(destlist[i].encinfo->dhkey.ec);
-                    }
+                }
+                if ((keyextype == KEYEX_ECDH_RSA) ||
+                        (keyextype == KEYEX_ECDH_ECDSA)) {
+                    free_EC_key(destlist[i].encinfo->dhkey.ec);
                 }
                 free(destlist[i].encinfo);
             }
