@@ -173,7 +173,7 @@ void create_cc_list(unsigned char **body, int *len)
  * Send out a CONG_CTRL message
  */
 void send_cong_ctrl(const struct finfo_t *finfo, double l_grtt,
-                    uint16_t l_cc_seq, uint32_t l_cc_rate, 
+                    uint16_t l_cc_seq, int64_t l_cc_rate, 
                     unsigned char *body, int len)
 {
     unsigned char *buf, *bodyptr, *encrypted, *outpacket;
@@ -353,8 +353,8 @@ void handle_tfmcc_ack_info(const struct finfo_t *finfo,
                            const struct tfmcc_ack_info_he *tfmcc, int hostidx)
 {
     struct timeval now, msgtime;
-    int flag_ss, flag_rtt, rate_1grtt;
-    unsigned client_rate;
+    int flag_ss, flag_rtt;
+    int64_t client_rate, rate_1grtt;
     double l_adv_grtt;
 
     gettimeofday(&now, NULL);
@@ -381,12 +381,12 @@ void handle_tfmcc_ack_info(const struct finfo_t *finfo,
     }
     if (hostidx == clr) {
         glog3(finfo, "Got clr CC response for round %d", ntohs(tfmcc->cc_seq));
-        rate_1grtt = (int)(datapacketsize / grtt);
+        rate_1grtt = (int64_t)(datapacketsize / grtt);
         if (!flag_ss && !flag_rtt) {
-            client_rate = (unsigned)((double)client_rate *
+            client_rate = (int64_t)((double)client_rate *
                     (adv_grtt / destlist[hostidx].rtt));
         }
-        if ((client_rate > (unsigned)rate + rate_1grtt) && !slowstart) {
+        if ((client_rate > (int64_t)rate + rate_1grtt) && !slowstart) {
             rate += rate_1grtt;
         } else {
             rate = client_rate;
@@ -399,22 +399,22 @@ void handle_tfmcc_ack_info(const struct finfo_t *finfo,
             slowstart = 1;
             rate = min_rate;
         }
-        if (rate < (int)(datapacketsize / grtt)) {
+        if (rate < (int64_t)(datapacketsize / grtt)) {
             slowstart = 1;
-            rate = (int)(datapacketsize / grtt);
+            rate = (int64_t)(datapacketsize / grtt);
         }
-        packet_wait = (int32_t)(1000000.0 * datapacketsize / rate);
+        packet_wait = (int64_t)(1000000000.0 * datapacketsize / rate);
         last_clr_time = now;
     } else {
         glog3(finfo, "Got CC response for round %d", ntohs(tfmcc->cc_seq));
         if (client_rate < cc_rate) {
-            cc_rate = (int)(client_rate * 0.9);
+            cc_rate = (int64_t)(client_rate * 0.9);
         }
         if (!flag_ss && !flag_rtt) {
-            client_rate = (unsigned)((double)client_rate *
+            client_rate = (int64_t)((double)client_rate *
                     (adv_grtt / destlist[hostidx].rtt));
         }
-        if ((client_rate < (unsigned)rate) || (clr == -1)) {
+        if ((client_rate < (int64_t)rate) || (clr == -1)) {
             glog3(finfo, "Selected new clr %s", destlist[hostidx].name);
             if (!clr_drop) {
                 rate = client_rate;
@@ -426,13 +426,13 @@ void handle_tfmcc_ack_info(const struct finfo_t *finfo,
                     slowstart = 1;
                     rate = min_rate;
                 }
-                if (rate < (int)(datapacketsize / grtt)) {
+                if (rate < (int64_t)(datapacketsize / grtt)) {
                     slowstart = 1;
-                    rate = (int)(datapacketsize / grtt);
+                    rate = (int64_t)(datapacketsize / grtt);
                 }
-                packet_wait = (int32_t)(1000000.0 * datapacketsize / rate);
+                packet_wait = (int64_t)(1000000000.0 * datapacketsize / rate);
                 rate_change = 1;
-            } else if (client_rate < (unsigned)rate) {
+            } else if (client_rate < rate) {
                 new_rate = client_rate;
             } else {
                 new_rate = rate;
@@ -448,7 +448,7 @@ void handle_tfmcc_ack_info(const struct finfo_t *finfo,
     if (l_adv_grtt > adv_grtt) {
         adv_grtt = l_adv_grtt;
     }
-    glog4(finfo, "rate = %d", rate);
+    glog4(finfo, "rate = " F_i64, rate);
 }
 
 /**
@@ -721,7 +721,7 @@ void print_status_file(const struct finfo_t *finfo, struct timeval start_time)
             break;
         case DEST_DONE:
             if (sync_preview) {
-                throughput = rate / 8;
+                throughput = (double)(rate / 8);
                 elapsed_time = finfo->size / (throughput * 1024);
             } else {
                 elapsed_time = diff_usec(finfo->deststate[i].time,
