@@ -1,7 +1,7 @@
 /*
  *  UFTP - UDP based FTP with multicast
  *
- *  Copyright (C) 2001-2019   Dennis A. Bush, Jr.   bush@tcnj.edu
+ *  Copyright (C) 2001-2020   Dennis A. Bush, Jr.   bush@tcnj.edu
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -1537,10 +1537,7 @@ void PRF(int hashtype, int bytes, const unsigned char *secret, int secret_len,
     int i, s_len, sha_buf_len, md5_buf_len;
     unsigned char *sha_buf, *md5_buf;
 
-    if (hashtype == HASH_SHA256) {
-        P_hash(HASH_SHA256, bytes, secret, secret_len, label,
-               seed, seed_len, outbuf, outbuf_len);
-    } else if (hashtype == HASH_SHA1) {
+    if (hashtype == HASH_SHA1) {
         // TLS 1.1 MD5/SHA1 combination
         md5_buf = safe_calloc(bytes + get_hash_len(HASH_MD5), 1);
         sha_buf = safe_calloc(bytes + get_hash_len(HASH_SHA1), 1);
@@ -1558,7 +1555,8 @@ void PRF(int hashtype, int bytes, const unsigned char *secret, int secret_len,
         free(md5_buf);
         free(sha_buf);
     } else {
-        *outbuf_len = 0;
+        P_hash(hashtype, bytes, secret, secret_len, label,
+               seed, seed_len, outbuf, outbuf_len);
     }
 }
 
@@ -1613,8 +1611,8 @@ int multicast_join(SOCKET s, uint32_t group_id, const union sockaddr_u *multi,
                    const struct iflist *addrlist, int addrlen,
                    const struct fp_list_t *fplist, int fplist_len)
 {
-    struct group_req greq;
-    struct group_source_req gsreq;
+    struct group_req greq = { 0 };
+    struct group_source_req gsreq = { 0 };
     int level = 0, i, j;
 
     for (i = 0; i < addrlen; i++) {
@@ -1665,8 +1663,8 @@ void multicast_leave(SOCKET s, uint32_t group_id, const union sockaddr_u *multi,
                      const struct iflist *addrlist, int addrlen,
                      const struct fp_list_t *fplist, int fplist_len)
 {
-    struct group_req greq;
-    struct group_source_req gsreq;
+    struct group_req greq = { 0 };
+    struct group_source_req gsreq = { 0 };
     int level = 0, i, j;
 
     for (i = 0; i < addrlen; i++) {
@@ -1717,8 +1715,8 @@ int multicast_join(SOCKET s, uint32_t group_id, const union sockaddr_u *multi,
                    const struct iflist *addrlist, int addrlen,
                    const struct fp_list_t *fplist, int fplist_len)
 {
-    struct ip_mreq mreq;
-    struct ipv6_mreq mreq6;
+    struct ip_mreq mreq = { 0 };
+    struct ipv6_mreq mreq6 = { 0 };
     int i;
 
     for (i = 0; i < addrlen; i++) {
@@ -1784,8 +1782,8 @@ void multicast_leave(SOCKET s, uint32_t group_id, const union sockaddr_u *multi,
                      const struct iflist *addrlist, int addrlen,
                      const struct fp_list_t *fplist, int fplist_len)
 {
-    struct ip_mreq mreq;
-    struct ipv6_mreq mreq6;
+    struct ip_mreq mreq = { 0 };
+    struct ipv6_mreq mreq6 = { 0 };
     int i;
 
     for (i = 0; i < addrlen; i++) {
