@@ -1,7 +1,7 @@
 /*
  *  UFTP - UDP based FTP with multicast
  *
- *  Copyright (C) 2001-2015   Dennis A. Bush, Jr.   bush@tcnj.edu
+ *  Copyright (C) 2001-2019   Dennis A. Bush, Jr.   bush@tcnj.edu
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -251,8 +251,8 @@ uint8_t quantize_grtt(double rtt);
 double unquantize_grtt(uint8_t rtt);
 uint8_t quantize_gsize(int size);
 int unquantize_gsize(uint8_t size);
-uint16_t quantize_rate(uint32_t size);
-uint32_t unquantize_rate(uint16_t size);
+uint16_t quantize_rate(int64_t size);
+int64_t unquantize_rate(uint16_t size);
 
 #endif  // _UFTP_COMMON_H
 
